#R-code LCA Group assignment

rm(list = ls())

library(timelineS)
library(lubridate)
library(ggplot2)
library(dplyr)
library(reshape2)
library(rPref)
library(mco)
library(MASS)

plot.timeline <- function(lifetime, events.name, start.Data, plot.Name){
  dataP <- data.frame(Events = events.name, Event_Datas = ymd(start.Data) + 
                        years(lifetime))
  timelineS(dataP, main = plot.Name, 
            labels = events.name, label.direction = "up", label.position = 3)
}

dist.Events <- function(lifetime, events, start.Date, option.Name){
  
  events <- sort(events, decreasing = T)
  
  distribution.events <- sapply(events, seq, from = 0, to = lifetime)
  
  all.events <- melt(distribution.events)
  
  if (length(dim(all.events)) == 2 && ncol(all.events) == 2) {
    colnames(all.events) <- c("frequency", "event")
  } else {
    all.events <- data.frame(frequency = rep(0, lifetime + 1), event = "DC")
  }
  
  all.events <- all.events[order(all.events$frequency),]
  
  unique.events <- all.events[!duplicated(all.events$frequency),]
  unique.events$event[which(unique.events$frequency == 0)] <- "CR"  
  
  return(unique.events)
}

#combine timelines
combine.lifeTimelines <- function(product.1, product.2, product.3, product.4, product.5, p1.dur, p2.dur, p3.dur, p4.dur, p5.dur) 
{
  
  
  base <- list(Names = c(), frequency = c(), duration = c())
  
  base$frequency <- sort(unique(c(product.1$frequency,
                                  product.2$frequency,
                                  product.3$frequency, 
                                  product.4$frequency, 
                                  product.5$frequency)),
                         decreasing = F)
  
  
  base$Names[1] <- "CR"
  base$duration[1] <- 0
  base$Names[length(base$frequency)] <- "END"
  base$duration[length(base$frequency)] <- 0
  
  #first function loop 
  for(index in 2:(length(base$frequency) - 1)) {
    
    phase.1 <- product.1$event[which(product.1$frequency == 
                                       base$frequency[index])] 
    phase.2 <- product.2$event[which(product.2$frequency == 
                                       base$frequency[index])]
    phase.3 <- product.3$event[which(product.3$frequency == 
                                       base$frequency[index])]
    phase.4 <- product.4$event[which(product.4$frequency == 
                                       base$frequency[index])]
    phase.5 <- product.5$event[which(product.5$frequency == 
                                       base$frequency[index])]
    
    if(length(phase.1)!= 0 && length(phase.2)!= 0 && 
       length(phase.3)!= 0 && length(phase.4)!= 0 && 
       length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.3, 
                                 phase.4, 
                                 phase.5)
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)], 
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p4.dur[which(names(p4.dur) == phase.4)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.2, phase.3, phase.4, phase.5)
      
      base$duration[index] <- max( 
        p2.dur[which(names(p2.dur) == phase.2)], 
        p3.dur[which(names(p3.dur) == phase.3)], 
        p4.dur[which(names(p4.dur) == phase.4)], 
        p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1,
                                 phase.3, 
                                 phase.4, 
                                 phase.5)
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p4.dur[which(names(p4.dur) == phase.4)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)!= 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.4, 
                                 phase.5)
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)],
                                  p4.dur[which(names(p4.dur) == phase.4)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.3, 
                                 phase.5)
      
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)], 
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.3, 
                                 phase.4)
      
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)], 
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.3)
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)], 
                                  p3.dur[which(names(p3.dur) == phase.3)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.4)
      
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)], 
                                  p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2, 
                                 phase.5)
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.3, 
                                 phase.4)
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.3, 
                                 phase.5)
      
      
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste( 
        phase.2, 
        phase.3, 
        phase.4)
      base$duration[index] <- max( 
        p2.dur[which(names(p2.dur) == phase.2)], 
        p3.dur[which(names(p3.dur) == phase.3)], 
        p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1)== 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste( 
        phase.2, 
        phase.3, 
        phase.5)
      base$duration[index] <- max(p2.dur[which(names(p2.dur) == phase.2)], 
                                  p3.dur[which(names(p3.dur) == phase.3)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    
    else if(length(phase.1) == 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste( 
        phase.3, 
        phase.4, 
        phase.5)
      base$duration[index] <- max( 
        p3.dur[which(names(p3.dur) == phase.3)], 
        p4.dur[which(names(p4.dur) == phase.4)], 
        p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.2)
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p2.dur[which(names(p2.dur) == phase.2)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.3)
      
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p3.dur[which(names(p3.dur) == phase.3)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)== 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.4)
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste(phase.1, 
                                 phase.5)
      base$duration[index] <- max(p1.dur[which(names(p1.dur) == phase.1)], 
                                  p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)!= 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste( 
        phase.2, 
        phase.3)
      base$duration[index] <- max( 
        p2.dur[which(names(p2.dur) == phase.2)], 
        p3.dur[which(names(p3.dur) == phase.3)])
    } 
    
    
    else if(length(phase.1)== 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste( 
        phase.2, 
        phase.4)
      base$duration[index] <- max( 
        p2.dur[which(names(p2.dur) == phase.2)], 
        p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste( 
        phase.2, 
        phase.5)
      base$duration[index] <- max( 
        p2.dur[which(names(p2.dur) == phase.2)], 
        p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- paste( 
        phase.3, 
        phase.4)
      base$duration[index] <- max( 
        p3.dur[which(names(p3.dur) == phase.3)], 
        p4.dur[which(names(p4.dur) == phase.4)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste( 
        phase.3, 
        phase.5)
      base$duration[index] <- max( 
        p3.dur[which(names(p3.dur) == phase.3)], 
        p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    else if(length(phase.1) == 0 && length(phase.2)== 0 && 
            length(phase.3)== 0 && length(phase.4)!= 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- paste( 
        phase.4, 
        phase.5)
      base$duration[index] <- max( 
        p4.dur[which(names(p4.dur) == phase.4)], 
        p5.dur[which(names(p5.dur) == phase.5)])
    } 
    
    
    
    else if(length(phase.1) != 0 && length(phase.2)== 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- phase.1
      base$duration[index] <- p1.dur[which(names(p1.dur) == phase.1)]
    } 
    
    
    else if(length(phase.1)== 0 && length(phase.2)!= 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- phase.2
      base$duration[index] <- p2.dur[which(names(p2.dur) == phase.2)]
    } 
    
    
    else if(length(phase.1)== 0 && length(phase.2)== 0 && 
            length(phase.3)!= 0 && length(phase.4)== 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- phase.3
      base$duration[index] <- p3.dur[which(names(p3.dur) == phase.3)]
    } 
    
    
    else if(length(phase.1)== 0 && length(phase.2)== 0 && 
            length(phase.3)== 0 && length(phase.4)!= 0 && 
            length(phase.5)== 0) { 
      
      base$Names[index] <- phase.4
      base$duration[index] <- p4.dur[which(names(p4.dur) == phase.4)]
    } 
    
    
    else if(length(phase.1)== 0 && length(phase.2)== 0 && 
            length(phase.3)== 0 && length(phase.4)== 0 && 
            length(phase.5)!= 0) { 
      
      base$Names[index] <- phase.5
      base$duration[index] <- p5.dur[which(names(p5.dur) == phase.5)]
    } 
    
    else {
      base$duration[index] <- 0
    }
  }
  return(base)
  
}


par(mfrow = c(2, 1))
start.Date <- "2024-01-01"
lifetime <- 50

#events

events.Op1.PavementPA <- c(IN.PA = 2, PW.PA = 1, PR.PA = 6, RS.PA = 9, END = lifetime)
duration.ev1.PavementPA <- c(IN.PA = 1, PW.PA = 1, PR.PA = 2, RS.PA = 2)

events.Op2.PavementPC <- c(IN.PC = 2, PW = 1, PR = 8, RS.PC = 10, END = lifetime)
duration.ev2.PavementPC <- c(IN.PC = 1, PW = 1, PR = 3, RS.PC = 5)

events.Op1.ColumnC35 <- c(IN.C3 = 7, CS.C3 = 13, END = lifetime)
duration.ev1.ColumnC35 <- c(IN.C3 = 1, CS.C3 = 10)

events.Op2.ColumnC25 <- c(IN.C2 = 6, CS.C2 = 17, END = lifetime)
duration.ev2.ColumnC25 <- c(IN.C2 = 1, CS.C2 = 10)

events.Op1.FloorWood <- c(IN.FW = 2, RF.FW = 7, END = lifetime)
duration.ev1.FloorWood <- c(IN.FW = 1, RF.FW = 2)

events.Op2.FloorConc <- c(RS = 7, OI = 7, RF.FC = 6, END = lifetime)
duration.ev2.FloorConc <- c(RS = 2, OI = 3, RF.FC = 2)

events.Op1.Wall <- c(LR = 25, KR = 75, IMR = 30, END = lifetime)
duration.ev1.Wall <- c(LR = 5, KR = 20, IMR = 10)

events.Op1.Tunnel <- c(BP = 10, DR = 45, END = lifetime)
duration.ev1.Tunnel <- c(BP = 2, DR = 3)

#individual design options
design.options.PavementPA <- list(design.Op1.Pavement <- "Permeable Asphalt")
design.options.PavementPC <- list(design.Op2.Pavement <- "Permeable Concrete")
design.options.ColumnC35 <- list(design.Op1.Column <- "Heavy Column (C35)")
design.options.ColumnC25 <- list(design.Op2.Column <-"Light Column (C25)")
design.options.FloorWood <- list(design.Op1.Floor <- "Wood Floor")
design.options.FloorConc <- list(design.Op2.Floor <- "Concrete Floor")
design.options.Wall <- list(design.Op1.Wall <- "Bamboo Inner Wall")
design.options.Tunnel <- list(design.Op1.Tunnel <- "Aesthetic Parking Tunnel")

#maintenance for individual design options
maintenance.PavementPA <- dist.Events(lifetime, events.Op1.PavementPA, 
                                      start.Date, design.options.PavementPA)
maintenance.PavementPC <- dist.Events(lifetime, events.Op2.PavementPC, 
                                      start.Date, design.options.PavementPC)
maintenance.ColumnC35 <- dist.Events(lifetime, events.Op1.ColumnC35, 
                                     start.Date, design.options.ColumnC35)
maintenance.ColumnC25 <- dist.Events(lifetime, events.Op2.ColumnC25, 
                                     start.Date, design.options.ColumnC25)
maintenance.FloorWood <- dist.Events(lifetime, events.Op1.FloorWood, 
                                     start.Date, design.options.FloorWood)
maintenance.FloorConc <- dist.Events(lifetime, events.Op2.FloorConc, 
                                     start.Date, design.options.FloorConc)
maintenance.Wall <- dist.Events(lifetime, events.Op1.Wall, 
                                start.Date, design.options.Wall)
maintenance.Tunnel <- dist.Events(lifetime, events.Op1.Tunnel, 
                                  start.Date, design.options.Tunnel)

#integrated interventions
integrated.interv1 <- combine.lifeTimelines(maintenance.Tunnel, 
                                            maintenance.Wall, 
                                            maintenance.PavementPA, 
                                            maintenance.ColumnC35, 
                                            maintenance.FloorConc, 
                                            duration.ev1.Tunnel, 
                                            duration.ev1.Wall, 
                                            duration.ev1.PavementPA, 
                                            duration.ev1.ColumnC35, 
                                            duration.ev2.FloorConc)

integrated.interv2 <- combine.lifeTimelines(maintenance.Tunnel, 
                                            maintenance.Wall, 
                                            maintenance.PavementPA, 
                                            maintenance.ColumnC25, 
                                            maintenance.FloorWood, 
                                            duration.ev1.Tunnel, 
                                            duration.ev1.Wall, 
                                            duration.ev1.PavementPA, 
                                            duration.ev2.ColumnC25, 
                                            duration.ev1.FloorWood)

integrated.interv3 <- combine.lifeTimelines(maintenance.Tunnel, maintenance.Wall, maintenance.PavementPC, maintenance.ColumnC35, maintenance.FloorConc,
                                            duration.ev1.Tunnel, duration.ev1.Wall, duration.ev2.PavementPC, duration.ev1.ColumnC35, duration.ev2.FloorConc)
integrated.interv4 <- combine.lifeTimelines(maintenance.Tunnel, maintenance.Wall, maintenance.PavementPC, maintenance.ColumnC25, maintenance.FloorWood, 
                                            duration.ev1.Tunnel, duration.ev1.Wall, duration.ev2.PavementPC, duration.ev2.ColumnC25, duration.ev1.FloorWood)


sum(integrated.interv1$duration)
sum(integrated.interv2$duration)
sum(integrated.interv3$duration)
sum(integrated.interv4$duration)

#design option 2 has the least days so we are choosing that design option----------------------
#in the next code we will explore design option 2

design.Optimal.classroom <- list(
  design.Optimal.classroom <- "C25 columns, Wood concrete composite floor, Bamboo walls, Permeable asphalt and concrete tunnel")

maintenance.Optimal.classroom <- plot.timeline(
  integrated.interv2$frequency, integrated.interv2$Names, start.Date, design.Optimal.classroom)


design.explore <- function(event1, event2, event3, event4, event5) {
  results <- c()
  for(i in 1: dim(event1)[1]) {
    ev1 <- unlist(event1[i, ])
    dist.1 <- dist.Events(lifetime, ev1, start.Date, "Tunnel")
    dur.ev1 <- ev1 / 2
    
    for(j in 1: dim(event2)[1]) {
      ev2 <- unlist(event2[j, ])
      dist.2 <- dist.Events(lifetime, ev2, start.Date, "Wall")
      dur.ev2 <- ev2 / 2
      
      for(k in 1: dim(event3)[1]) {
        ev3 <- unlist(event3[k, ])
        dist.3 <- dist.Events(lifetime, ev3, start.Date, "PavementPA")
        dur.ev3 <- ev3 / 2
        
        for(l in 1: dim(event4)[1]) {
          ev4 <- unlist(event4[l, ])
          dist.4 <- dist.Events(lifetime, ev4, start.Date, "ColumnC25")
          dur.ev4 <- ev4 / 2
          
          for(m in 1: dim(event5)[1]) {
            ev5 <- unlist(event5[m, ])
            dist.5 <- dist.Events(lifetime, ev5, start.Date, "FloorWood")
            dur.ev5 <- ev5 / 2
            
            
            combined.lifetime <- combine.lifeTimelines(dist.1, dist.2, dist.3, dist.4, dist.5, dur.ev1, dur.ev2, dur.ev3, dur.ev4, dur.ev5)
            
            
            
            min.dist.int <- min(abs(combined.lifetime$frequency[1 : (length(combined.lifetime$frequency) - 1)] - 
                                      combined.lifetime$frequency[2 : (length(combined.lifetime$frequency))] - 
                                      combined.lifetime$frequency[2 : (length(combined.lifetime$frequency))] - 
                                      combined.lifetime$frequency[2 : (length(combined.lifetime$frequency))] - 
                                      combined.lifetime$frequency[2 : (length(combined.lifetime$frequency))]))
            
            results <- rbind(results, c(ev1, ev2, ev3, ev4, ev5,
                                        sum(combined.lifetime$duration), min.dist.int))
            
          }
        }
      }
    }
  }
  
  return(as.data.frame(results))
}


n.grid <- 2


events.grid.PavementPA <- expand.grid(IN.PA = sample(seq(1, 3, by = 1), n.grid, replace = TRUE),
                                      PW.PA = sample(seq(1, 3, 1), n.grid, replace = TRUE),
                                      PR.PA = sample(seq(6, 8, 1), n.grid, replace = TRUE),
                                      RS.PA = sample(seq(9, 13, 1), n.grid, replace = TRUE))

events.grid.ColumnC25 <- expand.grid(IN.C2 = sample(seq(5, 10, by = 1), n.grid, replace = TRUE),
                                     CS.C2 = sample(seq(15, 20, 1), n.grid, replace = TRUE))

events.grid.FloorWood <- expand.grid(IN.FW = sample(seq(1, 3, by = 1), n.grid, replace = TRUE),
                                     RF.FW = sample(seq(5, 10, 1), n.grid, replace = TRUE))

events.grid.Wall <- expand.grid(LR = sample(seq(16, 30, by = 1), n.grid, replace = TRUE),
                                KR = sample(seq(50, 100, 1), n.grid, replace = TRUE),
                                IMR = sample(seq(5, 40, 1), n.grid, replace = TRUE))

events.grid.Tunnel <- expand.grid(BP = sample(seq(5, 15, 1), n.grid, replace = TRUE),
                                  DR = sample(seq(35, 55, 1), n.grid, replace = TRUE))

events.grid.PavementPA
events.grid.ColumnC25
events.grid.FloorWood
events.grid.Wall
events.grid.Tunnel 

response.space <- design.explore(events.grid.Tunnel, events.grid.Wall, events.grid.PavementPA, events.grid.ColumnC25, events.grid.FloorWood)
response.space

colnames(response.space)[colnames(response.space) == "V14"] <- "dur"
colnames(response.space)[colnames(response.space) == "V15"] <- "dist.inter"

p <- low(dur)* high(dist.inter)
p
sky <- psel(response.space, p)
sky

psel(response.space, p)
pareto2 <- psel(response.space, p, top = nrow(response.space))

ggplot(response.space, aes(x = dur, y = dist.inter)) +
  geom_point(shape = 21) +
  geom_point(data = pareto2, size = 3, aes(color = factor(pareto2$.level)))



show_front <- function(pref) {
  plot(response.space$dur, response.space$dist.inter)
  sky <- psel(response.space, pref)
  plot_front(response.space, pref, col = rgb(0, 0, 1))
  points(sky$dur, sky$dist.inter, lwd = 3) }

show_front(p)

p <- high(dur) * low(dist.inter)
show_front(p)





#---------------------------Upload CSV.file and change it to the path on your computer-------------------------------------------------------
LCI.materials <- read.csv("C:/Users/jorgt/OneDrive/Bureaublad/LCA_group_assignment/LCI_group.csv")
LCI.materials

Materials.split <- split(LCI.materials, LCI.materials$scope)
Materials.split
Materials.split$PA
PA.split <- split(Materials.split$PA, Materials.split$PA$material)
PA.split
PC.split <- split(Materials.split$PC, Materials.split$PC$material)
PC.split
C2.split <- split(Materials.split$C25, Materials.split$C25$material)
C2.split
C3.split <- split(Materials.split$C35, Materials.split$C35$material)
C3.split
FLW.split <- split(Materials.split$FW, Materials.split$FW$material)
FLW.split
FLC.split <- split(Materials.split$FC, Materials.split$FC$material)
FLC.split
W.split <- split(Materials.split$WL, Materials.split$WL$material)
W.split
T.split <- split(Materials.split$SC, Materials.split$SC$material)
T.split

#pavement-column-tunnel-floor-wall

LCA.Building <- function(Length, Width, Quantity, height, Components.Options, 
                         materials, dist.event)
{
  materials.split <- split(materials, materials$scope)
  #lines for intervention
  s <- summary(as.factor(dist.event$event))
  s2 <- as.data.frame(rbind(Freq = s), stringsAsFactors = F, row.names = 1:length(s))
  print(s2$IN.PA)
  
  Wall.thickness <- 0.24
  #Pavement options
  if(Components.Options == "PA")
  {
    
    Pavement.PA.surface <- Length * Width * height * Quantity
    Pavement.PA.base <- Length * Width * 0.06 * Quantity
    Pavement.PA.gravel <- Length * Width * 0.3 * Quantity
    
    
    intervention.PA.surface <- s2$CR + 0.01 * s2$IN.PA + 0.01 * (if(!is.null(s2$PW.PA)){s2$PW.PA} 
                                                                 else{0}) + 0.2 * (if(!is.null(s2$PR.PA)){s2$PR.PA} 
                                                                                   else{0}) + (if(!is.null(s2$RS.PA)){s2$RS.PA} 
                                                                                               else{0})
    intervention.PA.gravel <- s2$CR
    intervention.PA.base <- s2$CR
    PA.surface <- mutate(PA.split$`Surface layer total`, Building.Q = Pavement.PA.surface, 
                         interventions = intervention.PA.surface)
    PA.base <- mutate(PA.split$`Asphalt base layer total`, Building.Q = Pavement.PA.base, 
                      interventions = intervention.PA.base)
    PA.gravel <- mutate(PA.split$`Gravel base total`, Building.Q = Pavement.PA.gravel, 
                        interventions = intervention.PA.gravel)
    LCA.matrix <- rbind(PA.gravel, PA.base, PA.surface)
  }
  else if (Components.Options == "PC"){
    Pavement.PC.surface <- Length * Width * height * Quantity
    Pavement.PC.gravel <- Length * Width * 0.3 * Quantity
    intervention.PC.surface <- s2$CR + 0.01 * s2$IN.PC + 0.01 * (if(!is.null(s2$PW)){s2$PW} 
                                                                 else{0}) + 0.2 * (if(!is.null(s2$PR)){s2$PR} 
                                                                                   else{0}) + (if(!is.null(s2$RS.PC)){s2$RS.PC} 
                                                                                               else{0})
    intervention.PC.gravel <- s2$CR
    PC.surface <- mutate(PC.split$`Surface layer total`, Building.Q = Pavement.PC.surface, 
                         interventions = intervention.PC.surface)
    PC.gravel <- mutate(PC.split$`Gravel base total`, Building.Q = Pavement.PC.gravel, 
                        interventions = intervention.PC.gravel)
    LCA.matrix <- rbind(PC.gravel, PC.surface)
  }
  #column option c25
  if(Components.Options == "C25")
  {
    Total.column.volume.C25 <- Length * Width * height * Quantity
    
    intervention.C25 <- s2$CR + 0.01 * s2$IN.C2 + 0.05 * (if(!is.null(s2$CS.C2)){s2$CS.C2} else{0})
    
    Column.C25.CM <- mutate(C2.split$cement, Building.Q = Total.column.volume.C25, 
                            interventions = intervention.C25)
    Column.C25.C <- mutate(C2.split$`Coarse Aggregates`, Building.Q = Total.column.volume.C25, 
                           interventions = intervention.C25)
    Column.C25.F <- mutate(C2.split$`Fine Aggregates`, Building.Q = Total.column.volume.C25, 
                           interventions = intervention.C25)
    Column.C25.R <- mutate(C2.split$Reinforcement, Building.Q = Total.column.volume.C25, 
                           interventions = intervention.C25)
    LCA.matrix <- rbind(Column.C25.CM, Column.C25.C, Column.C25.F, Column.C25.R)
    
    
  }
  #Column option C35
  else if(Components.Options == "C35"){
    
    Total.column.volume.C35 <- Length * Width * height * Quantity
    
    intervention.C35 <- s2$CR + 0.01 * s2$IN.C3 + 0.05 * (if(!is.null(s2$CS.C3)){s2$CS.C3} else{0})
    Column.C35.CM <- mutate(C3.split$cement, Building.Q = Total.column.volume.C35, 
                            interventions = intervention.C35)
    Column.C35.C <- mutate(C3.split$`Coarse Aggregates`, Building.Q = Total.column.volume.C35, 
                           interventions = intervention.C35)
    Column.C35.F <- mutate(C3.split$`Fine Aggregates`, Building.Q = Total.column.volume.C35, 
                           interventions = intervention.C35)
    Column.C35.R <- mutate(C3.split$Reinforcement, Building.Q = Total.column.volume.C35, 
                           interventions = intervention.C35)
    LCA.matrix <- rbind(Column.C35.CM, Column.C35.C, Column.C35.F, Column.C35.R)
    
  }
  #floor options
  if(Components.Options == "WD"){
    
    Floor.Wood.volume <- Length * Width * height * Quantity
    intervention.Wood <- s2$CR + 0.01 * s2$IN.FW + 0.1 * (if(!is.null(s2$RF.FW)){s2$RF.FW} else{0})
    Floor.Wood <- mutate(FLW.split$`Wood-Concrete Composite Floor Slab`, Building.Q = Floor.Wood.volume, 
                         interventions = intervention.Wood)
    LCA.matrix <- Floor.Wood
    
    
    
  }
  else if(Components.Options == "CN"){
    
    Floor.Concrete.volume <- Length * Width * height * Quantity
    intervention.Concrete <- s2$CR + 0.2 * s2$RS + 0.05 * (if(!is.null(s2$OI)){s2$OI} else{0})
    + 0.1 * (if(!is.null(s2$RF.FC)){s2$RF.FC} else{0})
    Floor.Concrete <- mutate(FLC.split$`Concrete Floor Slab`, Building.Q = Floor.Concrete.volume, 
                             interventions = intervention.Concrete)
    LCA.matrix <- Floor.Concrete
    
  }
  #wall option
  if(Components.Options == "BM"){
    
    Wall.volume <- Length * Width * height * Quantity
    intervention.Wall <- s2$CR + 0.2 * s2$LR + 0.15 * (if(!is.null(s2$KR)){s2$KR} else{0})
    + 0.25 * (if(!is.null(s2$IMR)){s2$IMR} else{0})
    
    Wall.ins <- mutate(W.split$`Insulation Glass Wool`, Building.Q = Wall.volume, 
                       interventions = intervention.Wall)
    Wall.ply <- mutate(W.split$`ply-bamboo`, Building.Q = Wall.volume, 
                       interventions = intervention.Wall)
    LCA.matrix <- rbind(Wall.ply, Wall.ins)
    
  }
  #tunnel option
  if(Components.Options == "CN.t"){
    
    Tunnel.volume <- Length * Width * height * Quantity
    intervention.Tunnel <- s2$CR + 0.2 * s2$BP + 0.25 * (if(!is.null(s2$DR)){s2$DR} else{0})
    Tunnel.CM <- mutate(T.split$cement, Building.Q = Tunnel.volume, 
                        interventions = intervention.Tunnel)
    Tunnel.C <- mutate(T.split$`Coarse Aggregates`, Building.Q = Tunnel.volume, 
                       interventions = intervention.Tunnel)
    Tunnel.F <- mutate(T.split$`Fine Aggregates`, Building.Q = Tunnel.volume, 
                       interventions = intervention.Tunnel)
    Tunnel.R <- mutate(T.split$Reinforcement, Building.Q = Tunnel.volume, 
                       interventions = intervention.Tunnel)
    LCA.matrix <- rbind(Tunnel.R, Tunnel.F, Tunnel.C, Tunnel.CM)
    
    
  }
  
  LCA.matrix <- mutate(LCA.matrix, TotalMaterials.Q = 1 * Building.Q / 1000,
                       materials.LC = TotalMaterials.Q * interventions,
                       Energy.LC = materials.LC * Energy,
                       CO2.LC = materials.LC * CO2 * 1000,
                       NOx.LC = materials.LC * NOx * 1000,
                       SO2.LC = materials.LC * SO2 * 1000)
  
  LCA.results <- list(Energy = sum(LCA.matrix$Energy.LC),
                      CO2 = sum(LCA.matrix$CO2.LC),
                      NOx = sum(LCA.matrix$NOx.LC),
                      SO2 = sum(LCA.matrix$SO2.LC))
  return(LCA.results)
}


Pavement.options <- c("PA", "PC") 
Column.options <- c("C25", "C35")
Floor.options <- c("WD", "CN")
Wall.options <- c("BM")
Tunnel.options <- c("CN.t")

Floor.count <- 2
Ceiling.Height <- 3 #unit in m 

PA.width <- 40
PA.length <- 17
PA.height <- 0.04
PA.quantity <- 1

PC.width <- 40
PC.length <- 17
PC.height <- 0.2
PC.quantity <- 1

#i assume the column alternatives to have the same dimensions
C.width <- 0.4
C.length <- 0.25
C.height <- Ceiling.Height
C.quantity <- 23 * Floor.count

#i assume the concrete floor and the wood composite floors to be the same dimensions
FL.width <- 40
FL.length <- 17
FL.height <- 0.2
FL.quantity <- Floor.count

W.width <- 0.1 #thickness of bamboo wall
W.length <- 134 #total width of all walls combined present in the building
W.height <- Ceiling.Height
W.quantity <- 1

#this is an aesthetic car tunnel assumed to be 3x3 as a drive-thru and it is 4 metres long.
#i made the quantity 3 for the 2 walls and 1 roof slab for simplicity according to the code. 
T.width <- 4
T.length <- 3
T.height <- Ceiling.Height
T.quantity <- 3


Options.Pavement.PA <- LCA.Building(PA.length, PA.width, PA.quantity, PA.height, Pavement.options[1], 
                                    LCI.materials, maintenance.PavementPA)
Options.Pavement.PC <- LCA.Building(PC.length, PC.width, PC.quantity, PC.height, Pavement.options[2], 
                                    LCI.materials, maintenance.PavementPC)
Options.Column.C35 <- LCA.Building(C.length, C.width, C.quantity, C.height, Column.options[2], 
                                   LCI.materials, maintenance.ColumnC35)
Options.Column.C25 <- LCA.Building(C.length, C.width, C.quantity, C.height, Column.options[1], 
                                   LCI.materials, maintenance.ColumnC25)
Options.Floor.Wood <- LCA.Building(FL.length, FL.width, FL.quantity, FL.height, Floor.options[1], 
                                   LCI.materials, maintenance.FloorWood)
Options.Floor.Concrete <- LCA.Building(FL.length, FL.width, FL.quantity, FL.height, Floor.options[2], 
                                       LCI.materials, maintenance.FloorConc)
Options.Wall <- LCA.Building(W.length, W.width, W.quantity, W.height, Wall.options[1], 
                             LCI.materials, maintenance.Wall)
Options.Tunnel <- LCA.Building(T.length, T.width, T.quantity, T.height, Tunnel.options[1], 
                               LCI.materials, maintenance.Tunnel)



Energy.costs <- 0.128
CO2.unitcost <- 26 # per metric tone
NOX.unitCost <- 42 # per metric tone
SO2.unitCosts <- 85 # per metric tone


integrated.design.Op1 <- as.data.frame(list(Energy = Options.Pavement.PA$Energy + Options.Column.C35$Energy + Options.Floor.Concrete$Energy + Options.Wall$Energy + Options.Tunnel$Energy,
                                            CO2 = Options.Pavement.PA$CO2 + Options.Column.C35$CO2 + Options.Floor.Concrete$CO2 + Options.Wall$CO2 + Options.Tunnel$CO2,
                                            NOx = Options.Pavement.PA$NOx + Options.Column.C35$NOx + Options.Floor.Concrete$NOx + Options.Wall$NOx + Options.Tunnel$NOx,
                                            SO2 = Options.Pavement.PA$SO2 + Options.Column.C35$SO2 + Options.Floor.Concrete$SO2 + Options.Wall$SO2 + Options.Tunnel$SO2))

integrated.design.Op2 <- as.data.frame(list(Energy = Options.Pavement.PA$Energy + Options.Column.C25$Energy + Options.Floor.Wood$Energy + Options.Wall$Energy + Options.Tunnel$Energy,
                                            CO2 = Options.Pavement.PA$CO2 + Options.Column.C25$CO2 + Options.Floor.Wood$CO2 + Options.Wall$CO2 + Options.Tunnel$CO2,
                                            NOx = Options.Pavement.PA$NOx + Options.Column.C25$NOx + Options.Floor.Wood$NOx + Options.Wall$NOx + Options.Tunnel$NOx,
                                            SO2 = Options.Pavement.PA$SO2 + Options.Column.C25$SO2 + Options.Floor.Wood$SO2 + Options.Wall$SO2 + Options.Tunnel$SO2))

integrated.design.Op3 <- as.data.frame(list(Energy = Options.Pavement.PC$Energy + Options.Column.C35$Energy + Options.Floor.Concrete$Energy + Options.Wall$Energy + Options.Tunnel$Energy,
                                            CO2 = Options.Pavement.PC$CO2 + Options.Column.C35$CO2 + Options.Floor.Concrete$CO2 + Options.Wall$CO2 + Options.Tunnel$CO2,
                                            NOx = Options.Pavement.PC$NOx + Options.Column.C35$NOx + Options.Floor.Concrete$NOx + Options.Wall$NOx + Options.Tunnel$NOx,
                                            SO2 = Options.Pavement.PC$SO2 + Options.Column.C35$SO2 + Options.Floor.Concrete$SO2 + Options.Wall$SO2 + Options.Tunnel$SO2))

integrated.design.Op4 <- as.data.frame(list(Energy = Options.Pavement.PC$Energy + Options.Column.C25$Energy + Options.Floor.Wood$Energy + Options.Wall$Energy + Options.Tunnel$Energy, 
                                            CO2 = Options.Pavement.PC$CO2 + Options.Column.C25$CO2 + Options.Floor.Wood$CO2 + Options.Wall$CO2 + Options.Tunnel$CO2,
                                            NOx = Options.Pavement.PC$NOx + Options.Column.C25$NOx + Options.Floor.Wood$NOx + Options.Wall$NOx + Options.Tunnel$NOx,
                                            SO2 = Options.Pavement.PC$SO2 + Options.Column.C25$SO2 + Options.Floor.Wood$SO2 + Options.Wall$SO2 + Options.Tunnel$SO2))


integrated.design.Op1

integrated.design.Op2

integrated.design.Op3

integrated.design.Op4


#--------------------------------------------------multi objective optimization-------------------------------------------------
#design option 2 performs the best in this case

fitness <- function(x) {
  #define the output dimension 
  z <- numeric(7) 
  x <- round(x, 0)
  y <- expand.grid(IN.PA = x[1], PW.PA = x[2], PR.PA = x[3], RS.PA = x[4], 
                   IN.C2 = x[5], CS.C2 = x[6], 
                   IN.FW = x[7], RF.FW = x[8],
                   LR = x[9], KR = x[10], IMR = x[11],
                   BP = x[12], DR = x[13])
  
  dur.ev3 <- unlist(y[1:4] / 5) 
  dur.ev4 <- unlist(y[5:6] / 5)
  dur.ev5 <- unlist(y[7:8] / 5)
  dur.ev2 <- unlist(y[9:11] / 5)
  dur.ev1 <- unlist(y[12:13] / 5)
  
  dist.3 <- apply(y[1:4], 1, FUN = dist.Events, lifetime = lifetime, start.Date = start.Date) 
  dist.4 <- apply(y[5:6], 1, FUN = dist.Events, lifetime = lifetime, start.Date = start.Date)  
  dist.5 <- apply(y[7:8], 1, FUN = dist.Events, lifetime = lifetime, start.Date = start.Date)
  dist.2 <- apply(y[9:11], 1, FUN = dist.Events, lifetime = lifetime, start.Date = start.Date)
  dist.1 <- apply(y[12:13], 1, FUN = dist.Events, lifetime = lifetime, start.Date = start.Date)
  
  results <- combine.lifeTimelines(dist.1[[1]], dist.2[[1]], dist.3[[1]], dist.4[[1]], dist.5[[1]], 
                                   dur.ev1, dur.ev2, dur.ev3, dur.ev4, dur.ev5)
  z[1] <- sum(results[["duration"]])
  
  z[2] <- min(abs(results$frequency[1 : (length(results$frequency) - 1)] - 
                     results$frequency[2 : (length(results$frequency))] - 
                     results$frequency[2 : (length(results$frequency))] - 
                     results$frequency[2 : (length(results$frequency))] - 
                     results$frequency[2 : (length(results$frequency))]))
  
  Pavement.options <- c("PA", "PC") 
  Column.options <- c("C25", "C35")
  Floor.options <- c("WD", "CN")
  Wall.options <- c("BM")
  Tunnel.options <- c("CN.t")
  
  Floor.count <- 2
  Ceiling.Height <- 3 #unit in m 
  
  PA.width <- 40
  PA.length <- 17
  PA.height <- 0.04
  PA.quantity <- 1
  
  PC.width <- 40
  PC.length <- 17
  PC.height <- 0.2
  PC.quantity <- 1
  
  #i assume the column alternatives to have the same dimensions
  C.width <- 0.4
  C.length <- 0.25
  C.height <- Ceiling.Height
  C.quantity <- 23 * Floor.count
  
  #i assume the concrete floor and the wood composite floors to be the same dimensions
  FL.width <- 40
  FL.length <- 17
  FL.height <- 0.2
  FL.quantity <- Floor.count
  
  W.width <- 0.1 #thickness of bamboo wall
  W.length <- 134 #total width of all walls combined present in the building
  W.height <- Ceiling.Height
  W.quantity <- 1
  
  #this is an aesthetic car tunnel assumed to be 3x3 as a drive-thru and it is 4 metres long.
  #i made the quantity 3 for the 2 walls and 1 roof slab for simplicity according to the code. 
  T.width <- 4
  T.length <- 3
  T.height <- Ceiling.Height
  T.quantity <- 3
  
  Energy.costs <- 0.128
  CO2.unitcost <- 26
  NOx.unitCost <- 42
  SO2.unitCosts <- 85
  
 product.3.pavement <- LCA.Building(PA.length, PA.width, PA.quantity, PA.height, Pavement.options[1], 
                                     LCI.materials, dist.3[[1]])
  product.4.column <- LCA.Building(C.length, C.width, C.quantity, C.height, Column.options[1], 
                                   LCI.materials, dist.4[[1]])
  product.5.floor <- LCA.Building(FL.length, FL.width, FL.quantity, FL.height, Floor.options[1], 
                                  LCI.materials, dist.5[[1]])
  product.2.wall <- LCA.Building(W.length, W.width, W.quantity, W.height, Wall.options[1], 
                                 LCI.materials, dist.2[[1]])
  product.1.tunnel <- LCA.Building(T.length, T.width, T.quantity, T.height, Tunnel.options[1], 
                                  LCI.materials, dist.1[[1]])
  
  integrated.system <- as.data.frame(list(Energy = product.3.pavement$Energy + product.4.column$Energy + product.5.floor$Energy + product.2.wall$Energy + product.1.tunnel$Energy,
                                          CO2 = product.3.pavement$CO2 + product.4.column$CO2 + product.5.floor$CO2 + product.2.wall$CO2 + product.1.tunnel$CO2,
                                          NOx = product.3.pavement$NOx + product.4.column$NOx + product.5.floor$NOx + product.2.wall$NOx + product.1.tunnel$NOx, 
                                          SO2 = product.3.pavement$SO2 + product.4.column$SO2 + product.5.floor$SO2 + product.2.wall$SO2 + product.1.tunnel$SO2))
  integrated.system <- mutate(integrated.system, Costs = (Energy * Energy.costs + 
                                                            CO2 * CO2.unitcost +
                                                            NOx * NOx.unitCost +
                                                            SO2 * SO2.unitCosts) / 10^9)
  z[3] <- integrated.system$Energy 
  print(z[3]) 
  z[4] <- integrated.system$CO2 
  z[5] <- integrated.system$NOx 
  z[6] <- integrated.system$SO2 
  z[7] <- integrated.system$Costs
  return(z) 
}


#product.1.pavement <- LCA.Building(PA.length, PA.width, PA.quantity, PA.height, Pavement.options[1], 
 #                                  LCI.materials, maintenance.PavementPA)
#product.1.pavement
#product.2.column <- LCA.Building(C.length, C.width, C.quantity, C.height, Column.options[1], 
 #                                LCI.materials, maintenance.ColumnC25)
#product.2.column
#product.3.floor <- LCA.Building(FL.length, FL.width, FL.quantity, FL.height, Floor.options[1], 
 #                               LCI.materials, maintenance.FloorWood)
#product.3.floor
#product.4.wall <- LCA.Building(W.length, W.width, W.quantity, W.height, Wall.options[1], 
 #                              LCI.materials, maintenance.Wall)
#product.4.wall
#product.5.tunnel<- LCA.Building(T.length, T.width, T.quantity, T.height, Tunnel.options[1], 
 #                               LCI.materials, maintenance.Tunnel)
#product.5.tunnel

#events.grid.PavementPA <- expand.grid(IN.PA = sample(seq(1, 3, by = 1), n.grid, replace = TRUE),
#                                     PW.PA = sample(seq(1, 2, 1), n.grid, replace = TRUE),
#                                    PR.PA = sample(seq(6, 8, 1), n.grid, replace = TRUE),
#                                   RS.PA = sample(seq(9, 13, 1), n.grid, replace = TRUE))
#events.grid.ColumnC25 <- expand.grid(IN.C2 = sample(seq(5, 10, by = 1), n.grid, replace = TRUE),
#                                    CS.C2 = sample(seq(15, 20, 1), n.grid, replace = TRUE))
#events.grid.FloorWood <- expand.grid(IN.FW = sample(seq(1, 3, by = 1), n.grid, replace = TRUE),
#                                    RF.FW = sample(seq(5, 10, 1), n.grid, replace = TRUE))
#events.grid.Wall <- expand.grid(LR = sample(seq(16, 30, by = 1), n.grid, replace = TRUE),
#                               KR = sample(seq(50, 100, 1), n.grid, replace = TRUE),
#                              IMR = sample(seq(5, 40, 1), n.grid, replace = TRUE))
#events.grid.Tunnel <- expand.grid(BP = sample(seq(5, 15, 1), n.grid, replace = TRUE),
#                                 DR = sample(seq(35, 55, 1), n.grid, replace = TRUE))
#first trial


r2 <- nsga2(fitness, idim = 13, odim = 7, generations = 4, popsize = 40,
            lower.bounds = c(1, 1, 6, 9, 5, 15, 1, 5, 16, 50, 5, 5, 35),
            upper.bounds = c(3, 3, 8, 13, 10, 20, 3, 10, 30, 100, 40, 15, 55))

#second trial
#r2 <- nsga2(fitness, idim = 13, odim = 7, generations=10, popsize=100,
 #           lower.bounds=c(1, 1, 6, 9, 5, 15, 1, 5, 16, 50, 5, 5, 35),
  #          upper.bounds= c(3, 2, 8, 13, 10, 20, 3, 10, 30, 100, 40, 15, 55), vectorized = TRUE)

r2$value
r2Results <- as.data.frame(r2$value)
outNames <- c("duration", "interv.dist", "Energy", "CO2", "NOx", "SO2", "Costs" )
colnames(r2Results) <- outNames
r2Results

pareto3 <- as.data.frame(paretoFront(r2))
colnames(pareto3) <- outNames

ggplot(r2Results, aes(x = duration, y = Costs)) + geom_point(shape = 21) +
  geom_point(data = pareto3, size = 3, color="red") + geom_line(data = pareto3, color="blue")

input.params <- round(r2$par, 0)
all.results <- cbind(input.params, r2Results,
                     r2$pareto.optimal) 
colnames(all.results) <- c("IN.PA", "PW.PA", "PR.PA", 
                           "RS.PA", "IN.C2", "CS.C2", "IN.FW",
                           "RF.FW", "LR", "KR", "IMR", "BP", "DR",
                           "duration", "interv.dist", 
                           "Energy", "CO2", "NOx", "SO2", "Costs", "pareto")

all.results

par(mfrow = c(1,1))
parcoord(all.results[, 1:21], var.label = T, 
         col = ifelse(all.results$pareto == TRUE, "indianred",
                      "skyblue2"), lty = ifelse(all.results$pareto == TRUE, 1, 3),
         lwd = ifelse(all.results$pareto == TRUE, 3, 1))
